


#ifndef __TOTEM_PL_PARSER_BUILTINS_H__
#define __TOTEM_PL_PARSER_BUILTINS_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "/usr/src/ports/totem-pl-parser/totem-pl-parser-3.10.8-1.x86_64/src/totem-pl-parser-3.10.8/plparse/totem-pl-parser.h" */
GType totem_pl_parser_result_get_type (void) G_GNUC_CONST;
#define TOTEM_TYPE_PL_PARSER_RESULT (totem_pl_parser_result_get_type())
GType totem_pl_parser_type_get_type (void) G_GNUC_CONST;
#define TOTEM_TYPE_PL_PARSER_TYPE (totem_pl_parser_type_get_type())
GType totem_pl_parser_error_get_type (void) G_GNUC_CONST;
#define TOTEM_TYPE_PL_PARSER_ERROR (totem_pl_parser_error_get_type())
G_END_DECLS

#endif /* __TOTEM_PL_PARSER_BUILTINS_H__ */



